@@ -425,8 +425,11 @@ class IndexesProxy(dict):
         if response.status == 200:
             indexes_dict = json.loads(content)
             for index_name, index_properties in indexes_dict.items():
+                index_props = {}
+                for key, val in index_properties.items():
+                    index_props[str(key)] = val
                 indexes_dict[index_name] = Index(self._index_for, index_name,
-                                                 **index_properties)
+                                                 **index_props)
             return indexes_dict
         elif response.status == 404:
             raise NotFoundError(response.status, "Indexes not found")
@@ -448,7 +451,10 @@ class IndexesProxy(dict):
         if name not in self._dict:
             response, content = Request().post(self.url, data=data)
             if response.status == 201:
-                result_dict = json.loads(content)
+                loaded_dict = json.loads(content)
+                result_dict = {}
+                for key, val in loaded_dict.items():
+                    result_dict[str(key)] = val
                 self._dict[name] = Index(self._index_for, name, **result_dict)
             else:
                 raise StatusException(response.status, "Invalid data sent")
@@ -934,15 +940,15 @@ class Extension(object):
             for param, value in kwargs.items():
                 has_param = (len([np for np in self.parameters
                                      if np["name"] == param]) != 0)
-                if key not in params_kwargs and has_param:
-                    params_kwargs[key] = value
+                if param not in params_kwargs and has_param:
+                    params_kwargs[param] = value
         return self._parse_types(params_kwargs)
 
     def _parse_types(self, kwargs):
         params_kwargs = {}
-        for key, value in kwargs.items():
+        for param, value in kwargs.items():
             if isinstance(value, Base):
-                params_kwargs[key] = value.url
+                params_kwargs[param] = value.url
             else:
-                params_kwargs[key] = value
+                params_kwargs[param] = value
         return params_kwargs
